import { APIClient } from "./ApiClient";

export interface ServerConfig {
  local_auth_enabled: boolean;
  oidc_auth_enabled: boolean;
  iso_mimetypes: string[];
  iso_max_size: number;
}

let config: ServerConfig | null = null;

export class ServerApi {
  /**
   * Get server configuration
   */
  static async LoadConfig(): Promise<void> {
    config = (
      await APIClient.exec({
        uri: "/server/static_config",
        method: "GET",
      })
    ).data;
  }

  /**
   * Get cached configuration
   */
  static get Config(): ServerConfig {
    if (config === null) throw new Error("Missing configuration!");
    return config;
  }
}
